@@ -44,29 +44,7 @@ G_BEGIN_DECLS
 
 /* type macros */
 #define GNC_TYPE_TREE_VIEW_COMMODITY            (gnc_tree_view_commodity_get_type ())
-#define GNC_TREE_VIEW_COMMODITY(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNC_TYPE_TREE_VIEW_COMMODITY, GncTreeViewCommodity))
-#define GNC_TREE_VIEW_COMMODITY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GNC_TYPE_TREE_VIEW_COMMODITY, GncTreeViewCommodityClass))
-#define GNC_IS_TREE_VIEW_COMMODITY(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNC_TYPE_TREE_VIEW_COMMODITY))
-#define GNC_IS_TREE_VIEW_COMMODITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNC_TYPE_TREE_VIEW_COMMODITY))
-#define GNC_TREE_VIEW_COMMODITY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNC_TYPE_TREE_VIEW_COMMODITY, GncTreeViewCommodityClass))
-
-/* typedefs & structures */
-typedef struct
-{
-    GncTreeView gnc_tree_view;
-    int stamp;
-} GncTreeViewCommodity;
-
-typedef struct
-{
-    GncTreeViewClass gnc_tree_view;
-} GncTreeViewCommodityClass;
-
-
-
-/* Get the GType for an GncTreeViewCommodity object. */
-GType gnc_tree_view_commodity_get_type (void);
-
+G_DECLARE_FINAL_TYPE (GncTreeViewCommodity, gnc_tree_view_commodity, GNC, TREE_VIEW_COMMODITY, GncTreeView)
 
 /** @name Commodity Tree View Constructors
  @{ */
@@ -96,7 +74,7 @@ GtkTreeView *gnc_tree_view_commodity_new (QofBook *book,
 
 /** Configure (by name) the set of visible columns in an commodity tree
  *  view.  By default, only the commodity name column is show.  The
- *  avalible list of columns can be found in the file
+ *  available list of columns can be found in the file
  *  gnc-tree-view-commodity.c
  *
  *  @param view A pointer to an commodity tree view.
@@ -136,7 +114,7 @@ typedef gboolean (*gnc_tree_view_commodity_cm_filter_func)(gnc_commodity*, gpoin
  *  thinks should possibly show.  The filter may perform any actions
  *  necessary on the commodity to decide whether it should be shown or
  *  not.  (I.E. Check type, placeholder status, etc.)  If the filter
- *  returns TRUE then the commodity wil be displayed.
+ *  returns TRUE then the commodity will be displayed.
  *
  *  @param view A pointer to an commodity tree view.
  *
@@ -208,7 +186,7 @@ gnc_commodity * gnc_tree_view_commodity_get_selected_commodity  (GncTreeViewComm
  *
  *  @param view A pointer to an commodity tree view.
  *
- *  @param The commodity to select.
+ *  @param commodity The commodity to select.
  */
 void gnc_tree_view_commodity_select_commodity (GncTreeViewCommodity *view, gnc_commodity *commodity);
 
