@@ -1,15 +1,15 @@
 ;; report-utilities.scm -- Reporting utilities
 ;;
-;; This program is free software; you can redistribute it and/or    
-;; modify it under the terms of the GNU General Public License as   
-;; published by the Free Software Foundation; either version 2 of   
-;; the License, or (at your option) any later version.              
-;;                                                                  
-;; This program is distributed in the hope that it will be useful,  
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of   
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    
-;; GNU General Public License for more details.                     
-;;                                                                  
+;; This program is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU General Public License as
+;; published by the Free Software Foundation; either version 2 of
+;; the License, or (at your option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program; if not, contact:
 ;;
@@ -126,7 +126,7 @@
 ;; html-renderer.
 (define (gnc:monetary->string value)
   (xaccPrintAmount
-   (gnc:gnc-monetary-amount value) 
+   (gnc:gnc-monetary-amount value)
    (gnc-commodity-print-info (gnc:gnc-monetary-commodity value) #t)))
 
 ;; True if the account is of type currency, stock, or mutual-fund
@@ -160,9 +160,9 @@
 ;; Returns only those accounts out of the list <accounts> which have
 ;; one of the type identifiers in typelist.
 (define (gnc:filter-accountlist-type typelist accounts)
-  (filter (lambda (a) 
-	    (and (not (null? a)) (member (xaccAccountGetType a) typelist)))
-	  accounts))
+  (filter (lambda (a)
+            (and (not (null? a)) (member (xaccAccountGetType a) typelist)))
+          accounts))
 
 ;; Decompose a given list of accounts 'accounts' into an alist
 ;; according to their types. Each element of alist is a list, whose
@@ -171,29 +171,29 @@
 ;; category.
 (define (gnc:decompose-accountlist accounts)
   (map (lambda (x) (cons
-		    (car x)
-		    (gnc:filter-accountlist-type (cdr x) accounts)))
+                    (car x)
+                    (gnc:filter-accountlist-type (cdr x) accounts)))
        (list
-	(cons ACCT-TYPE-ASSET
-	      (list ACCT-TYPE-ASSET ACCT-TYPE-BANK ACCT-TYPE-CASH
+        (cons ACCT-TYPE-ASSET
+              (list ACCT-TYPE-ASSET ACCT-TYPE-BANK ACCT-TYPE-CASH
                     ACCT-TYPE-CHECKING ACCT-TYPE-SAVINGS
                     ACCT-TYPE-MONEYMRKT ACCT-TYPE-RECEIVABLE
                     ACCT-TYPE-STOCK ACCT-TYPE-MUTUAL
                     ACCT-TYPE-CURRENCY))
-	(cons ACCT-TYPE-LIABILITY
+        (cons ACCT-TYPE-LIABILITY
               (list ACCT-TYPE-LIABILITY ACCT-TYPE-PAYABLE ACCT-TYPE-CREDIT
                     ACCT-TYPE-CREDITLINE))
-	(cons ACCT-TYPE-EQUITY (list ACCT-TYPE-EQUITY))
-	(cons ACCT-TYPE-INCOME (list ACCT-TYPE-INCOME))
-	(cons ACCT-TYPE-EXPENSE (list ACCT-TYPE-EXPENSE))
-	(cons ACCT-TYPE-TRADING (list ACCT-TYPE-TRADING)))))
+        (cons ACCT-TYPE-EQUITY (list ACCT-TYPE-EQUITY))
+        (cons ACCT-TYPE-INCOME (list ACCT-TYPE-INCOME))
+        (cons ACCT-TYPE-EXPENSE (list ACCT-TYPE-EXPENSE))
+        (cons ACCT-TYPE-TRADING (list ACCT-TYPE-TRADING)))))
 
 ;; Returns the name of the account type as a string, and in its plural
 ;; form (as opposed to xaccAccountGetTypeStr which gives the
 ;; singular form of the word).
 (define (gnc:account-get-type-string-plural type)
   (assoc-ref
-   (list 
+   (list
     (cons ACCT-TYPE-BANK (G_ "Bank"))
     (cons ACCT-TYPE-CASH (G_ "Cash"))
     (cons ACCT-TYPE-CREDIT (G_ "Credits"))
@@ -218,7 +218,7 @@
 ;; 'accounts', excluding the 'exclude-commodity'.
 (define (gnc:accounts-get-commodities accounts exclude-commodity)
   (delete exclude-commodity
-	  (sort-and-delete-duplicates
+          (sort-and-delete-duplicates
            (map xaccAccountGetCommodity accounts)
            (lambda (a b)
              (gnc:string-locale<? (gnc-commodity-get-unique-name a)
@@ -232,12 +232,6 @@
   (let ((root (gnc-get-current-root-account)))
     (gnc-account-get-tree-depth root)))
 
-;; Return accountslist *and* their descendant accounts
-(define (gnc:accounts-and-all-descendants accountslist)
-  (sort-and-delete-duplicates
-   (apply append accountslist (map gnc-account-get-descendants accountslist))
-   gnc:account-path-less-p equal?))
-
 ;;; Here's a statistics collector...  Collects max, min, total, and makes
 ;;; it easy to get at the mean.
 
@@ -272,10 +266,10 @@
   (let ((value 0))
     (lambda (action amount)
       (case action
-	((add) (if (number? amount)
+        ((add) (if (number? amount)
                    (set! value (+ amount value))))
-	((total) value)
-	(else (gnc:warn "bad value-collector action: " action))))))
+        ((total) value)
+        (else (gnc:warn "bad value-collector action: " action))))))
 
 ;; A commodity collector. This is intended to handle multiple
 ;; currencies' amounts. The amounts are accumulated via 'add, the
@@ -293,7 +287,7 @@
 ;; Note amounts are rounded to the commodity's SCU.
 ;;
 ;; The functions:
-;;   'add <commodity> <amount>: Add the given amount to the 
+;;   'add <commodity> <amount>: Add the given amount to the
 ;;       appropriate currencies' total balance.
 ;;   'format <fn> #f: Call the function <fn> (where fn takes two
 ;;       arguments) for each commodity with the arguments <commodity>
@@ -302,11 +296,11 @@
 ;;   'merge <commodity-collector> #f: Merge the given other
 ;;       commodity-collector into this one, adding all currencies'
 ;;       balances, respectively.
-;;   'minusmerge <commodity-collector> #f: Merge the given other 
+;;   'minusmerge <commodity-collector> #f: Merge the given other
 ;;       commodity-collector into this one (like above) but subtract
 ;;       the other's currencies' balance from this one's balance,
 ;;       respectively.
-;;   'reset #f #f: Delete everything that has been accumulated 
+;;   'reset #f #f: Delete everything that has been accumulated
 ;;       (even the fact that any commodity showed up at all).
 ;;   'getpair <commodity> signreverse?: Returns the two-element-list
 ;;       with the <commodity> and its corresponding balance. If
@@ -322,32 +316,32 @@
 (define (gnc:make-commodity-collector)
   ;; the association list of (commodity . value-collector) pairs.
   (let ((commoditylist '()))
-    
+
     ;; helper function to add a (commodity . value) pair to our list.
     ;; If no pair with this commodity exists, we will create one.
     (define (add-commodity-value commodity value)
       (let ((pair (assoc commodity commoditylist)))
-	(unless pair
-	  (set! pair (list commodity (gnc:make-value-collector)))
-	  (set! commoditylist (cons pair commoditylist)))
-	((cadr pair) 'add value)))
-    
+        (unless pair
+          (set! pair (list commodity (gnc:make-value-collector)))
+          (set! commoditylist (cons pair commoditylist)))
+        ((cadr pair) 'add value)))
+
     ;; helper function to walk an association list, adding each
     ;; (commodity . collector) pair to our list at the appropriate
     ;; place
     (define (add-commodity-clist clist)
       (cond ((null? clist) '())
-	    (else (add-commodity-value 
-		   (caar clist) 
-		   ((cadar clist) 'total #f))
-		  (add-commodity-clist (cdr clist)))))
+            (else (add-commodity-value
+                   (caar clist)
+                   ((cadar clist) 'total #f))
+                  (add-commodity-clist (cdr clist)))))
 
     (define (minus-commodity-clist clist)
       (cond ((null? clist) '())
-	    (else (add-commodity-value 
-		   (caar clist) 
-		   (- ((cadar clist) 'total #f)))
-		  (minus-commodity-clist (cdr clist)))))
+            (else (add-commodity-value
+                   (caar clist)
+                   (- ((cadar clist) 'total #f)))
+                  (minus-commodity-clist (cdr clist)))))
 
     ;; helper function walk the association list doing a callback on
     ;; each key-value pair.
@@ -362,29 +356,32 @@
     (define (getpair c sign?)
       (let* ((pair (assoc c commoditylist))
              (total (if pair ((cadr pair) 'total #f) 0)))
-	(list c (if sign? (- total) total))))
+        (list c (if sign? (- total) total))))
 
     ;; helper function which is given a commodity and returns a
     ;; <gnc:monetary> value, whose amount may be 0.
     (define (getmonetary c sign?)
       (let* ((pair (assoc c commoditylist))
              (total (if pair ((cadr pair) 'total #f) 0)))
-	(gnc:make-gnc-monetary c (if sign? (- total) total))))
-    
+        (gnc:make-gnc-monetary c (if sign? (- total) total))))
+
+    (define (not-zero? l) (not (zero? ((cadr l) 'total #f))))
+
     ;; Dispatch function
     (lambda (action commodity amount)
       (case action
-	((add) (add-commodity-value commodity amount))
-	((merge) (add-commodity-clist
+        ((add) (add-commodity-value commodity amount))
+        ((merge) (add-commodity-clist
                   (commodity 'list #f #f)))
-	((minusmerge) (minus-commodity-clist
+        ((minusmerge) (minus-commodity-clist
                        (commodity 'list #f #f)))
-	((format) (process-commodity-list commodity commoditylist))
-	((reset) (set! commoditylist '()))
-	((getpair) (getpair commodity amount))
-	((getmonetary) (getmonetary commodity amount))
-	((list) commoditylist) ; this one is only for internal use
-	(else (gnc:warn "bad commodity-collector action: " action))))))
+        ((format) (process-commodity-list commodity commoditylist))
+        ((reset) (set! commoditylist '()))
+        ((getpair) (getpair commodity amount))
+        ((getmonetary) (getmonetary commodity amount))
+        ((remove-zeros) (set! commoditylist (filter not-zero? commoditylist)))
+        ((list) commoditylist) ; this one is only for internal use
+        (else (gnc:warn "bad commodity-collector action: " action))))))
 
 (define (gnc:commodity-collector-get-negated collector)
   (let ((negated (gnc:make-commodity-collector)))
@@ -514,7 +511,7 @@
          (let ((head-result (split->elt (car splits))))
            (lp (cdr splits) rest (cons head-result result) head-result))))))))
 
-;; This works similar as above but returns a commodity-collector, 
+;; This works similar as above but returns a commodity-collector,
 ;; thus takes care of children accounts with different currencies.
 (define (gnc:account-get-comm-balance-at-date
          account date include-children?)
@@ -581,10 +578,10 @@
 ;; (e.g. gnc-reverse-balance) should return #t if the
 ;; account's balance sign should get reversed. Returns a
 ;; commodity-collector.
-(define (gnc:accounts-get-balance-helper 
-	 accounts get-balance-fn reverse-balance-fn)
+(define (gnc:accounts-get-balance-helper
+         accounts get-balance-fn reverse-balance-fn)
   (let ((collector (gnc:make-commodity-collector)))
-    (for-each 
+    (for-each
      (lambda (acct)
        (collector
         (if (reverse-balance-fn acct) 'minusmerge 'merge)
@@ -593,49 +590,16 @@
      accounts)
     collector))
 
-;; Adds all accounts' balances, where the balances are determined with
-;; the get-balance-fn. Intended for usage with a profit and loss
-;; report, hence a) only the income/expense accounts are regarded, and
-;; b) the result is sign reversed. Returns a commodity-collector.
-(define (gnc:accounts-get-comm-total-profit accounts 
-					    get-balance-fn)
-  (issue-deprecation-warning "gnc:accounts-get-comm-total-profit deprecated.")
-  (gnc:accounts-get-balance-helper
-   (gnc:filter-accountlist-type (list ACCT-TYPE-INCOME ACCT-TYPE-EXPENSE) accounts)
-   get-balance-fn
-   (lambda(x) #t)))
-
-;; Adds all accounts' balances, where the balances are determined with
-;; the get-balance-fn. Only the income accounts are regarded, and
-;; the result is sign reversed. Returns a commodity-collector.
-(define (gnc:accounts-get-comm-total-income accounts 
-					    get-balance-fn)
-  (issue-deprecation-warning "gnc:accounts-get-comm-total-income deprecated.")
-  (gnc:accounts-get-balance-helper
-   (gnc:filter-accountlist-type (list ACCT-TYPE-INCOME) accounts)
-   get-balance-fn
-   (lambda(x) #t)))
-
-;; Adds all accounts' balances, where the balances are determined with
-;; the get-balance-fn. Only the expense accounts are regarded, and
-;; the result is sign reversed. Returns a commodity-collector.
-(define (gnc:accounts-get-comm-total-expense accounts 
-                                             get-balance-fn)
-  (issue-deprecation-warning "gnc:accounts-get-comm-total-expense deprecated.")
-  (gnc:accounts-get-balance-helper
-   (gnc:filter-accountlist-type (list ACCT-TYPE-EXPENSE) accounts)
-   get-balance-fn
-   (lambda(x) #t)))
 
 ;; Adds all accounts' balances, where the balances are determined with
 ;; the get-balance-fn. Intended for usage with a balance sheet, hence
 ;; a) the income/expense accounts are ignored, and b) no signs are
 ;; reversed at all. Returns a commodity-collector.
-(define (gnc:accounts-get-comm-total-assets accounts 
-					    get-balance-fn)
+(define (gnc:accounts-get-comm-total-assets accounts
+                                            get-balance-fn)
   (gnc:accounts-get-balance-helper
    (filter (lambda (a) (not (gnc:account-is-inc-exp? a)))
-	   accounts)
+           accounts)
    get-balance-fn
    (lambda(x) #f)))
 
@@ -669,58 +633,23 @@
 (define (gnc:accountlist-get-comm-balance-at-date-with-closing accountlist date)
   (gnc:account-get-trans-type-balance-interval-with-closing accountlist #f #f date))
 
-;; utility function - ensure that a query matches only non-voids.  Destructive.
-(define (gnc:query-set-match-non-voids-only! query book)
-  (issue-deprecation-warning
-   "gnc:query-set-match-non-voids-only! is deprecated. add query for\
-(logand CLEARED-ALL (lognot CLEARED-VOIDED)) instead.")
-  (let ((temp-query (qof-query-create-for-splits)))
-    (qof-query-set-book temp-query book)
-
-    (xaccQueryAddClearedMatch
-     temp-query
-     CLEARED-VOIDED
-     QOF-QUERY-AND)
-
-    (let ((inv-query (qof-query-invert temp-query)))
-      (qof-query-merge-in-place query inv-query QOF-QUERY-AND)
-      (qof-query-destroy inv-query)
-      (qof-query-destroy temp-query))))
-
-;; utility function - ensure that a query matches only voids.  Destructive
-
-(define (gnc:query-set-match-voids-only! query book)
-  (issue-deprecation-warning
-   "gnc:query-set-match-non-voids-only! is deprecated. add CLEARED-VOIDED \
-query instead.")
-  (let ((temp-query (qof-query-create-for-splits)))
-    (qof-query-set-book temp-query book)
-
-    (xaccQueryAddClearedMatch
-     temp-query
-     CLEARED-VOIDED
-     QOF-QUERY-AND)
-
-    (qof-query-merge-in-place query temp-query QOF-QUERY-AND)
-    (qof-query-destroy temp-query)))
-
 (define (gnc:split-voided? split)
   (let ((trans (xaccSplitGetParent split)))
     (xaccTransGetVoidStatus trans)))
 
 (define (gnc:report-starting report-name)
   (gnc-window-show-progress (format #f
-				     (G_ "Building '~a' report ...")
-				     (G_ report-name))
-			    0))
+                                     (G_ "Building '~a' report …")
+                                     (G_ report-name))
+                            0))
 
 (define (gnc:report-render-starting report-name)
   (gnc-window-show-progress (format #f
-				     (G_ "Rendering '~a' report ...")
-				     (if (string-null? report-name)
-					 (G_ "Untitled")
-					 (G_ report-name)))
-			    0))
+                                     (G_ "Rendering '~a' report …")
+                                     (if (string-null? report-name)
+                                         (G_ "Untitled")
+                                         (G_ report-name)))
+                            0))
 
 (define (gnc:report-percent-done percent)
   (if (> percent 100)
@@ -740,7 +669,7 @@ query instead.")
 
 ;; function to count the total number of splits to be iterated
 (define (gnc:accounts-count-splits accounts)
-  (apply + (map length (map xaccAccountGetSplitList accounts))))
+  (fold (lambda (a b) (+ b (length (xaccAccountGetSplitList a)))) 0 accounts))
 
 ;; Sums up any splits of a certain type affecting a set of accounts.
 ;; the type is an alist '((str "match me") (cased #f) (regexp #f))
@@ -776,7 +705,7 @@ query instead.")
 ;; Return the splits that match an account list, date range, and (optionally) type
 ;; where type is defined as an alist like:
 ;; '((str "match me") (cased #f) (regexp #f) (closing #f))
-;; where str, cased, and regexp define a pattern match on transaction deseriptions 
+;; where str, cased, and regexp define a pattern match on transaction deseriptions
 ;; and "closing" matches transactions created by the book close command.  If "closing"
 ;; is given as #t then only closing transactions will be returned, if it is #f then
 ;; only non-closing transactions will be returned, and if it is omitted then both
@@ -986,7 +915,7 @@ query instead.")
 (define (not-APAR? s)
   (not (xaccAccountIsAPARType (xaccAccountGetType (xaccSplitGetAccount s)))))
 ;; analyse a payment transaction and return a 3-element vector:
-;; (vector invoices opposing-splits overpayment)
+;; (vector invoices overpayment opposing-splits)
 ;;
 ;; invoices: a list of (cons invoice inv-APAR-split)
 ;; opposing-splits: a list of (list pmt-APAR-split partial-amount derived?)
@@ -994,44 +923,49 @@ query instead.")
 ;;                 amount does not match the transaction amount
 ;; overpayment: a number indicating overpayment amount
 (define (gnc:payment-txn->payment-info txn)
-  (let lp ((splits (xaccTransGetSplitList txn))
-           (invoices '())
-           (overpayment 0)
-           (opposing-splits '()))
-    (match splits
-      (() (vector invoices opposing-splits overpayment))
-      (((? not-APAR? split) . rest)
-       (lp rest invoices (+ overpayment (xaccSplitGetAmount split))
-           opposing-splits))
-      ((split . rest)
-       (let* ((lot (xaccSplitGetLot split))
-              (lot-all-splits (gnc-lot-get-split-list lot)))
-         (define split=? (cut equal? <> split))
-         (match (gncInvoiceGetInvoiceFromLot lot)
-           (() (let lp1 ((lot-splits lot-all-splits)
-                         (overpayment overpayment)
-                         (opposing-splits opposing-splits))
-                 (match lot-splits
-                   (() (lp rest invoices overpayment opposing-splits))
-                   (((? split=?) . tail) (lp1 tail overpayment opposing-splits))
-                   ((s . tail)
-                    (let* ((lot-bal (gnc-lot-get-balance lot))
-                           (lot-bal (if (sign-equal? lot-bal (xaccSplitGetAmount s))
-                                        0 lot-bal))
-                           (derived? (not (zero? lot-bal)))
-                           (partial-amount
-                            (fold
-                             (lambda (a b)
-                               (if (equal? s a) b (+ b (xaccSplitGetAmount a))))
-                             (- lot-bal) lot-all-splits)))
-                      (lp1 tail (+ overpayment partial-amount)
-                           (cons (list s partial-amount derived?)
-                                 opposing-splits)))))))
-           (inv
-            (lp rest
-                (cons (cons inv split) invoices)
-                (+ overpayment (xaccSplitGetAmount split))
-                opposing-splits))))))))
+  (let* ((apar-split (xaccTransGetFirstAPARAcctSplit txn #t))
+        (apar-acct (xaccSplitGetAccount apar-split)))
+    (let lp ((splits (xaccTransGetSplitList txn))
+            (invoices '())
+            (overpayment 0)
+            (opposing-splits '()))
+      (match splits
+        (() (vector invoices opposing-splits overpayment))
+        (((? not-APAR? split) . rest)
+        (gnc:msg "next " (gnc:strify split) " overpayment " (+ overpayment (xaccSplitConvertAmount split apar-acct)))
+        (lp rest invoices (+ overpayment (xaccSplitConvertAmount split apar-acct))
+            opposing-splits))
+        ((split . rest)
+        (let* ((lot (xaccSplitGetLot split))
+                (lot-all-splits (gnc-lot-get-split-list lot)))
+          (define split=? (cut equal? <> split))
+          (match (gncInvoiceGetInvoiceFromLot lot)
+            (() (let lp1 ((lot-splits lot-all-splits)
+                          (overpayment overpayment)
+                          (opposing-splits opposing-splits))
+                  (match lot-splits
+                    (() (lp rest invoices overpayment opposing-splits))
+                    (((? split=?) . tail) (lp1 tail overpayment opposing-splits))
+                    ((s . tail)
+                      (let* ((lot-bal (gnc-lot-get-balance lot))
+                            (lot-bal (if (sign-equal? lot-bal (xaccSplitConvertAmount s apar-acct))
+                                          0 lot-bal))
+                            (derived? (not (zero? lot-bal)))
+                            (partial-amount
+                              (fold
+                              (lambda (a b)
+                                (if (equal? s a) b (+ b (xaccSplitConvertAmount a apar-acct))))
+                              (- lot-bal) lot-all-splits)))
+                        (gnc:msg "next " (gnc:strify s) " overpayment " (+ overpayment partial-amount))
+                        (lp1 tail (+ overpayment partial-amount)
+                            (cons (list s partial-amount derived?)
+                                  opposing-splits)))))))
+            (inv
+              (gnc:msg "next " (gnc:strify split) " overpayment " (+ overpayment (xaccSplitConvertAmount split apar-acct)))
+              (lp rest
+                  (cons (cons inv split) invoices)
+                  (+ overpayment (xaccSplitConvertAmount split apar-acct))
+                  opposing-splits)))))))))
 
 ;; create a stepped list, then add a date in the infinite future for
 ;; the "current" bucket
@@ -1045,7 +979,7 @@ query instead.")
 (define-public (gnc:owner-splits->aging-list splits num-buckets
                                              to-date date-type receivable?)
   (gnc:msg "processing " (qof-print-date to-date) " date-type " date-type
-           "receivable? " receivable?)
+           " receivable? " receivable?)
   (let ((bucket-dates (make-extended-interval-list to-date (- num-buckets 3)))
         (buckets (make-vector num-buckets 0)))
     (define (addbucket! idx amt)
@@ -1063,10 +997,11 @@ query instead.")
                          (xaccSplitGetParent (car splits))))
                (lot (gncInvoiceGetPostedLot invoice))
                (lot-splits (gnc-lot-get-split-list lot))
+               (apar-acct (gncInvoiceGetPostedAcc invoice))
                (bal (fold
                      (lambda (a b)
                        (if (<= (xaccTransGetDate (xaccSplitGetParent a)) to-date)
-                           (+ (xaccSplitGetAmount a) b)
+                           (+ (xaccSplitConvertAmount a apar-acct) b)
                            b))
                      0 lot-splits))
                (bal (if receivable? bal (- bal)))
@@ -1145,6 +1080,10 @@ query instead.")
             (map gnc:strify (coll 'format gnc:make-gnc-monetary #f))))
   (define (value-collector->str coll)
     (format #f "coll<~a>" (coll 'total #f)))
+  (define (option-get-description option)
+    (format #f "Option<~a/~a>"
+            (GncOption-get-section option)
+            (GncOption-get-name option)))
   (define (procedure->str proc)
     (format #f "Proc<~a>"
             (or (procedure-name proc) "unk")))
@@ -1206,6 +1145,7 @@ query instead.")
                              (if (eq? (car d) 'absolute)
                                  (qof-print-date (cdr d))
                                  (gnc:strify (cdr d)))))
+      (try option-get-description)
       (try monetary-collector->str)
       (try value-collector->str)
       (try procedure->str)
@@ -1332,7 +1272,7 @@ query instead.")
     (define (maybe-date time64)         ;handle INT-MAX differently
       (if (= 9223372036854775807 time64) "?" (qof-print-date time64)))
     (define (maybe-trunc str)
-      (if (> (string-length str) 20) (string-append (substring str 0 17) "...") str))
+      (if (> (string-length str) 20) (string-append (substring str 0 17) "…") str))
     (define (inv-amt->string inv amt)
       (gnc:monetary->string
        (gnc:make-gnc-monetary
